@@ -179,7 +179,7 @@ impl InnerWebView {
         if let Some(window) = widget.parent() {
           // Safe to unwrap unless this is not from tao
           let window: gtk::Window = window.downcast().unwrap();
-          if !window.is_decorated() && window.is_resizable() {
+          if !window.is_decorated() && window.is_resizable() && !window.is_maximized() {
             if let Some(window) = window.window() {
               if let Some((cx, cy)) = event.root_coords() {
                 if let Some(device) = event.device() {
@@ -366,7 +366,6 @@ impl InnerWebView {
     self.webview.grab_focus();
   }
 
-  /// Open the web inspector which is usually called dev tool.
   #[cfg(any(debug_assertions, feature = "devtools"))]
   pub fn open_devtools(&self) {
     if let Some(inspector) = WebViewExt::inspector(&*self.webview) {
@@ -376,7 +375,6 @@ impl InnerWebView {
     }
   }
 
-  /// Close the web inspector which is usually called dev tool.
   #[cfg(any(debug_assertions, feature = "devtools"))]
   pub fn close_devtools(&self) {
     if let Some(inspector) = WebViewExt::inspector(&*self.webview) {
@@ -384,11 +382,14 @@ impl InnerWebView {
     }
   }
 
-  /// Gets the devtool window's current vibility state.
   #[cfg(any(debug_assertions, feature = "devtools"))]
   pub fn is_devtools_open(&self) -> bool {
     self.is_inspector_open.load(Ordering::Relaxed)
   }
+
+  pub fn zoom(&self, scale_factor: f64) {
+    WebViewExt::set_zoom_level(&*self.webview, scale_factor);
+  }
 }
 
 pub fn platform_webview_version() -> Result<String> {
